/*
 * Copyright 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 * Danbooru Client is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Danbooru Client is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Danbooru Client. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "test_danbooru_post.h"
#include "../danboorupost.h"
#include "../utils.h"

#include <QFile>
#include <QJsonDocument>
#include <QJsonObject>

void TestDanbooruPost::initTestCase()
{
    QFile file;
    file.setFileName(m_fileName);
    file.open(QIODevice::ReadOnly | QIODevice::Text);
    bool ok;
    m_data = Danbooru::parseDanbooruResult(file.readAll(), &ok).toList().at(0).toMap();
}

void TestDanbooruPost::testPostLoading()
{
    m_post = new Danbooru::DanbooruPost(m_data);

    QFETCH(int, postId);
    QFETCH(int, postWidth);
    QFETCH(int, postHeight);
    QFETCH(int, fileSize);
    QFETCH(QSet<QString>, postTags);
    QFETCH(QUrl, fileUrl);
    QFETCH(QUrl, thumbnailUrl);
    QFETCH(QUrl, sampleUrl);
    QFETCH(Danbooru::DanbooruPost::Rating, rating);

    QCOMPARE(m_post->id(), postId);
    QCOMPARE(m_post->width(), postWidth);
    QCOMPARE(m_post->height(), postHeight);
    QCOMPARE(m_post->size(), fileSize);
    QCOMPARE(m_post->tags(), postTags);
    QCOMPARE(m_post->fileUrl(), fileUrl);
    QCOMPARE(m_post->thumbnailUrl(), thumbnailUrl);
    QCOMPARE(m_post->sampleUrl(), sampleUrl);
    QCOMPARE(m_post->rating(), rating);
    QCOMPARE(m_post->pixmap().isNull(), true);
}

void TestDanbooruPost::testPostLoading_data()
{
    QTest::addColumn<int>("postId");
    QTest::addColumn<int>("postWidth");
    QTest::addColumn<int>("postHeight");
    QTest::addColumn<int>("fileSize");
    QTest::addColumn<QSet< QString >>("postTags");
    QTest::addColumn<QUrl>("fileUrl");
    QTest::addColumn<QUrl>("thumbnailUrl");
    QTest::addColumn<QUrl>("sampleUrl");
    QTest::addColumn<Danbooru::DanbooruPost::Rating>("rating");

    QSet<QString> tags = {"azuki_(sayori)", "coconut_(sayori)", "game_cg", "nekopara",
                          "sayori"};

    QTest::newRow("konachan") << 205621     // id
                              << 1280       // width
                              << 720        // height
                              << 885610     // file_size
                              << tags       // tags
                              << QUrl("http://konachan.net/image/eb36c568af4f4e4ea2f59eda7d8c802d/Konachan.com%20-%20205621%20azuki_%28sayori%29%20coconut_%28sayori%29%20game_cg%20nekopara%20sayori.png")
                              << QUrl("http://konachan.net/data/preview/eb/36/eb36c568af4f4e4ea2f59eda7d8c802d.jpg")
                              << QUrl("http://konachan.net/jpeg/eb36c568af4f4e4ea2f59eda7d8c802d/Konachan.com%20-%20205621%20azuki_%28sayori%29%20coconut_%28sayori%29%20game_cg%20nekopara%20sayori.jpg")
                              << Danbooru::DanbooruPost::Safe;
}


QTEST_MAIN(TestDanbooruPost)

